@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -289,7 +286,9 @@ main (int argc, char* argv[])
   if (!awt.implemented())
   {
     fprintf (stderr, "AWT is not implemented on this platform.\n");
-    return 0;
+    fprintf (stderr, "This can happen if X11 Development libraries\n"); 
+    fprintf (stderr, "were missing when configure was executed.\n"); 
+    return 1;
   }
 
   /* have to set the path after first awt */
