@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -27,11 +24,13 @@
 #include "stoolkit/STypes.h"
 #include "stoolkit/SIOStream.h"
 #include "swidget/SUniPrint.h"
+#include "swidget/SIconFactory.h"
 #include <swindow/SPrinter.h>
 #include <swindow/SScriptProcessor.h>
 #include <stdlib.h>
 
 static int translateHighlightMode (const SString& hl);
+static int getLineNumber (const SString& s);
 
 /**
  * A caret that redraws itself differently for lr and rl text 
@@ -83,6 +82,7 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props)
      sprintf (fnc, "untitled%d.txt", fn); 
    }
    currentFileName = SString (fnc);
+
    SFile cfile (currentFileName);
    if (cfile.size() < 0) break;
   }  
@@ -131,6 +131,7 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props)
     )
   );
   toolbar->setListener (this);
+  
 
   messagelabel = new SMessageLabel (props);
   unsigned int messagelabeHeight = messagelabel->getPreferredSize().height;
@@ -293,11 +294,6 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props)
             props["yudit.command.caret.right.foreground"]);
   slider->setSliderBackground (props["yudit.slider.background"]);
 
-
-  SString version("Yudit-");
-  version.append (SD_YUDIT_VERSION);
-  setTitle (version);
-
   SDimension pw = toolbar->getPreferredSize();
   /* get the dimension */
   SDimension ms(props["yudit.default.geometry"]);
@@ -325,6 +321,7 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props)
 #endif
   toolbar->setParagraphSeparator (ft, true);
 
+  int lineNum = -1;
   if (args.size())
   {
     SString comm ("open -yes ");
@@ -334,7 +331,20 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props)
     unsigned int i;
     for (i=1; i<args.size(); i++)
     {
-      if (args[i] == SString("-e") && i+1 < args.size())
+      if (args[i] == SString("--"))
+      {
+        if (i+1 < args.size())
+        {
+          filename = args[i+1];
+        }
+        break;
+      }
+      // +NUMBER
+      else if (getLineNumber (args[i]) > 0)
+      {
+        lineNum = getLineNumber (args[i]);
+      }
+      else if (args[i] == SString("-e") && i+1 < args.size())
       {
         i++;
         enc = args[i];
@@ -393,10 +403,19 @@ SYudit::SYudit (const SStringVector& args, const SProperties& props)
   }
 
   toolbar->setFileName(currentFileName, lastencoding);
+  setFileTitle ();
+  SIcon* icon = SIconFactory::getIcon("Yudit");
+  setApplicationImage (icon->getImage ());
+
 //fprintf (stderr, "SYudit.cpp EDITOR FOCUS REQUEST\n");
   setDropListener (this, SStringVector ("text/uri-list,text/plain"));
   showFreeHand (currentInput=="freehand");
   editor->setFocus ();
+  if (lineNum > 0)
+  {
+    editor->setCursorIndex(SCursorIndex((unsigned int)(lineNum-1), 0, true));
+  }
+  
 }
 
 SYudit::~SYudit ()
@@ -583,7 +602,8 @@ SYudit::buttonPressed (void* src, int which, bool accel)
     command->setFocus();
     break;
   case SToolBar::SS_PRINT:
-    messagelabel->setMessage (translate ("print -o file -p printer -break"), 
+    messagelabel->setMessage (
+      translate ("usage: print [-o file] [-p printer] [-e exec] [-break] [-hsize header-font-size]"), 
        SMessageLabel::SS_INFO);
     pstr.append ("print ");
     pstr.append (lastprinterOption);
@@ -886,6 +906,9 @@ SYudit::print (const SStringVector& args, const SString& str)
   bool shownl = false;
   bool islpr = false;
 
+  SPrinter::SMedia media = SPrinter::A4;
+  SPrinter::SOrientation orientation = SPrinter::PORTRAIT;
+
   for (i=1; i<args.size(); i++)
   {
     if ((args[i] == "-printer" || args[i] =="-p") && i+1 < args.size())
@@ -903,6 +926,66 @@ SYudit::print (const SStringVector& args, const SString& str)
       i++;
       filename = completeFileName (args[i]);
     }
+    else if ((args[i] == "-m" || args[i] =="-media") && i+1 < args.size())
+    {
+      i++;
+      if (args[i] == "A3")
+      {
+        media = SPrinter::A3;
+      }
+      else if (args[i] == "A4")
+      {
+        media = SPrinter::A4;
+      }
+      else if (args[i] == "A5")
+      {
+        media = SPrinter::A5;
+      }
+      else if (args[i] == "B4")
+      {
+        media = SPrinter::B4;
+      }
+      else if (args[i] == "B5")
+      {
+        media = SPrinter::B5;
+      }
+      else if (args[i] == "Executive")
+      {
+        media = SPrinter::Executive;
+      }
+      else if (args[i] == "Folio")
+      {
+        media = SPrinter::Folio;
+      }
+      else if (args[i] == "Ledger")
+      {
+        media = SPrinter::Ledger;
+      }
+      else if (args[i] == "Legal")
+      {
+        media = SPrinter::Legal;
+      }
+      else if (args[i] == "Letter")
+      {
+        media = SPrinter::Letter;
+      }
+      else if (args[i] == "Quarto")
+      {
+        media = SPrinter::Quarto;
+      }
+      else if (args[i] == "Statement")
+      {
+        media = SPrinter::Statement;
+      }
+      else if (args[i] == "Tabloid")
+      {
+        media = SPrinter::Tabloid;
+      }
+      else
+      {
+        media = SPrinter::A4;
+      }
+    }
     else if (args[i] == "-exec" && i+1 < args.size())
     {
       i++;
@@ -949,6 +1032,10 @@ SYudit::print (const SStringVector& args, const SString& str)
     {
       shownl = true;
     }
+    else if (args[i] == "-L" || args[i] =="-landscape")
+    {
+      orientation = SPrinter::LANDSCAPE;
+    }
     else
     {
       break;
@@ -1022,7 +1109,10 @@ SYudit::print (const SStringVector& args, const SString& str)
   }
   SWriter writer(os);
   SString fontName = toolbar->fonts[toolbar->currentFont];
-  SUniPrint uniPrint(writer, fontName, hsized, fontName, messagebar->fontSize);
+  
+  SPrinter p (writer, SPrinter::POSTSCRIPT, media, orientation);
+  SUniPrint uniPrint(p, fontName, hsized, fontName, messagebar->fontSize);
+
   SString text = editor->getText();
 
   uniPrint.setDocumentEmbedding (toolbar->currentEmbedding);
@@ -1247,6 +1337,8 @@ SYudit::load (const SStringVector& args, const SString& str)
       command->clear();
       currentFileName = filename;
       toolbar->setFileName(currentFileName, lastencoding);
+      setFileTitle ();
+
       editor->clear();
       editor->setFocus();
       toolbar->setModified(false);
@@ -1334,7 +1426,10 @@ SYudit::load (const SStringVector& args, const SString& str)
   lastencoding = encode;
   command->clear();
   currentFileName = filename;
+
   toolbar->setFileName(currentFileName, lastencoding);
+  setFileTitle ();
+
   messagelabel->setMessage (ems, 
        sft ?  SMessageLabel::SS_WARN : SMessageLabel::SS_INFO);
   const STextIndex* sindex = caretIndex.get (filename);
@@ -1442,6 +1537,8 @@ SYudit::save (const SStringVector& args, const SString& str)
   lastencoding = encode;
   currentFileName = filename;
   toolbar->setFileName(currentFileName, lastencoding);
+  setFileTitle();
+
   command->clear();
   command->historyEnd();
 
@@ -1908,6 +2005,9 @@ SYudit::createFileDialog () // If needed
   if (fontSize < 2.0) fontSize = 2.0;
   fileDialog->setFont (font, fontSize);
   fileDialog->setFileTypes (addEnc);
+
+  SIcon* icon = SIconFactory::getIcon("Yudit");
+  fileDialog->setApplicationImage (icon->getImage ());
 }
 
 void
@@ -1933,6 +2033,9 @@ SYudit::createKMapDialog ()
   /* button size bug workaround */
   SDimension dim = kmapDialog->getPreferredSize();
   kmapDialog->resize(SDimension(dim.width+2, dim.height+2));
+
+  SIcon* icon = SIconFactory::getIcon("Yudit");
+  kmapDialog->setApplicationImage (icon->getImage ());
 }
 
 void
@@ -1956,6 +2059,9 @@ SYudit::createTextDialog ()
   if (fontSize < 2.0) fontSize = 2.0;
 
   textDialog->setFont (font, fontSize);
+
+  SIcon* icon = SIconFactory::getIcon("Yudit");
+  textDialog->setApplicationImage (icon->getImage ());
 }
 
 /*
@@ -2153,6 +2259,37 @@ SYudit::addMytoolPrefix (SString* executable)
   return true;
 }
 
+/**
+ * Set the title to current filename.
+ */
+void 
+SYudit::setFileTitle ()
+{
+  SDir d;
+  /* this will chop off filename */
+  d.cd (currentFileName);
+  SString dn = d.getName ();
+  SString fn;
+  SStringVector v(currentFileName, "/");
+  if (v.size())
+  {
+    fn.append (v[v.size()-1]);
+  }
+
+  SString t = fn;
+  // FIXME: do we need the directory?
+  dn = "";
+  if (dn.size () > 0)
+  {
+    t.append (" (");
+    t.append (dn);
+    t.append (")");
+  }
+  t.append ("  Yudit-");
+  t.append (SD_YUDIT_VERSION);
+  setTitle (t);
+}
+
 /**
  * Translate our string highlight mode to an integer
  * @return -1 if it can not be translated.
@@ -2178,3 +2315,30 @@ translateHighlightMode (const SString& hl)
   }
   return -1;
 }
+
+/**
+ * \return negative on fail or the number if it is specified 
+ *  as +NUMBER.
+ */
+static int 
+getLineNumber (const SString& s)
+{
+  if (s.size() < 2 || s.peek(0) != '+') return -1;
+  int line = 0;
+  for (unsigned int i=1; i<s.size(); i++)
+  {
+    if (s.peek(i) >= '0' && s.peek(i) <= '9')
+    {
+      if (line < 100000000) 
+      {
+        line = line * 10;
+        line += (s.peek(i) - '0');
+      }
+    }
+    else
+    {
+      return -1;
+    }
+  } 
+  return line;
+}
