@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -936,7 +933,7 @@ SBMapItemVector::addKLine (int _index, const char* _line, const unsigned char* _
       to = toOut;
       if (kcIndex==0)
       {
-        key[kcSize[0]] = (unsigned char) value;
+        key[(int)kcSize[0]] = (unsigned char) value;
       }
       else
       {
@@ -963,7 +960,7 @@ SBMapItemVector::addKLine (int _index, const char* _line, const unsigned char* _
       value = to[0];
       if (kcIndex==0)
       {
-        key[kcSize[0]] = (unsigned char) value;
+        key[(int)kcSize[0]] = (unsigned char) value;
       }
       else
       {
@@ -980,7 +977,7 @@ SBMapItemVector::addKLine (int _index, const char* _line, const unsigned char* _
     fprintf (stderr, "error: kmap map is empty. \n");
     return -1;
   }
-  key[kcSize[0]] = 0;
+  key[(int)kcSize[0]] = 0;
   code[kcSize[1]*2] = 0;
 
   // Now you can see the limitation of kmaps. No matchsize!
