@@ -1,7 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 1997-2005  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -604,6 +604,7 @@ getIndicCluster (unsigned int scriptcode,
      if (prevchartype != SD_INDIC_CONSONANT_BASE 
            && prevchartype != SD_INDIC_CONSONANT_BELOW_BASE
            && prevchartype != SD_INDIC_CONSONANT_POST_BASE
+           && prevchartype != SD_INDIC_CONSONANT_DEAD
            && prevchartype != SD_INDIC_HALANT
            && prevchartype != SD_INDIC_NUKTA
            && prevchartype != SD_INDIC_INDEP_VOWEL)
@@ -639,6 +640,7 @@ getIndicCluster (unsigned int scriptcode,
      if (prevchartype != SD_INDIC_CONSONANT_BASE 
            && prevchartype != SD_INDIC_CONSONANT_BELOW_BASE
            && prevchartype != SD_INDIC_CONSONANT_POST_BASE
+           && prevchartype != SD_INDIC_CONSONANT_DEAD
            && prevchartype != SD_INDIC_HALANT
            && prevchartype != SD_INDIC_NUKTA
            && prevchartype != SD_INDIC_INDEP_VOWEL)
@@ -693,6 +695,7 @@ getIndicCluster (unsigned int scriptcode,
            && prevchartype != SD_INDIC_CONSONANT_BASE
            && prevchartype != SD_INDIC_CONSONANT_BELOW_BASE
            && prevchartype != SD_INDIC_CONSONANT_POST_BASE
+           && prevchartype != SD_INDIC_CONSONANT_DEAD
 	   && prevchartype != SD_INDIC_NUKTA)
      {
        nextLig = nextLigature (scriptcode, 
@@ -732,6 +735,7 @@ getIndicCluster (unsigned int scriptcode,
            && prevchartype != SD_INDIC_CONSONANT_POST_BASE
            && prevchartype != SD_INDIC_HALANT
            && prevchartype != SD_INDIC_NUKTA
+           && prevchartype != SD_INDIC_CONSONANT_DEAD
 	   && prevchartype != SD_INDIC_INDEP_VOWEL)
      {
         yuditClusterError = "Dependent vowel should be preceded by consonant, nukta, halant or independent vowel.";
@@ -757,7 +761,8 @@ getIndicCluster (unsigned int scriptcode,
    case SD_INDIC_CONSONANT_BELOW_BASE:
    case SD_INDIC_CONSONANT_POST_BASE:
      if (ret->size() > 0 && prevchartype != SD_INDIC_HALANT 
-           && prevchartype != SD_INDIC_ZWJ)
+           && prevchartype != SD_INDIC_ZWJ 
+           && prevchartype != SD_INDIC_CONSONANT_DEAD)
      {
        yuditClusterError = "Consonant should be preceded by halant or nukta or ZWJ";
        nextLig = nextLigature (scriptcode, &unicode.array()[index], i-index);
@@ -778,6 +783,7 @@ getIndicCluster (unsigned int scriptcode,
             && ct != SD_INDIC_TOP_VOWEL 
             && ct != SD_INDIC_LEFT_VOWEL
             && ct != SD_INDIC_LEFT_RIGHT_VOWEL
+            && ct != SD_INDIC_CONSONANT_DEAD
             && ct != SD_INDIC_RIGHT_VOWEL)
        {
           if (ret->size()==1) return index;
@@ -817,6 +823,7 @@ getIndicCluster (unsigned int scriptcode,
      }
      if (prevchartype != SD_INDIC_CONSONANT_BASE 
         && prevchartype != SD_INDIC_CONSONANT_BELOW_BASE
+        && prevchartype != SD_INDIC_CONSONANT_DEAD
         && prevchartype != SD_INDIC_CONSONANT_POST_BASE)
      {
        yuditClusterError = "Nukta should be preceded by a consonant.";
@@ -887,6 +894,11 @@ getIndicCluster (unsigned int scriptcode,
      }
      ret->append (next);
      break;
+   case SD_INDIC_CONSONANT_DEAD:
+     // Finish the cluster - I dont know any better solution.
+     nextLig = nextLigature (scriptcode, &unicode.array()[index], i-index+1);
+     if (nextLig) ret->append (nextLig);
+     return i+1;
    default:
      if (ret->size()==0)
      {
