@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -42,7 +39,7 @@ public:
 protected:
   virtual void keyPressed (SWindow * w, SKey key, const SString& s,
           bool ctrl, bool shift, bool meta);
-  virtual void SDialog::buttonPressed (void* source, const SAccelerator* acc);
+  virtual void buttonPressed (void* source, const SAccelerator* acc);
   virtual bool close (SPanel* comp);
   SType    type;
   SPanel*  dialogPanel;
