@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -143,6 +140,13 @@ SFileDialog::getFileTypes() const
   return fileTypeVector;
 }
 
+void
+SFileDialog::setApplicationImage (const SImage& image)
+{
+  getComponentWindow()->setApplicationImage (image);
+  textDialog->setApplicationImage (image);
+}
+
 void
 SFileDialog::fileTypeChanged (const SString& _filetype)
 {
