@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -71,11 +68,12 @@
 
 #include "icons/SS_RL_XPM.xpm"
 #include "icons/SS_LR_XPM.xpm"
+#include "icons/SS_Yudit_XPM.xpm"
 
-struct {
+struct _icon_map {
   const char*  name;
   char** icon;
-} icon_map [] = {
+} icon_map[] = {
   { "Caution", SS_Caution },
   { "Inform", SS_Inform   },
   { "Open", SS_Open       },
@@ -122,6 +120,8 @@ struct {
   { "EmbedLeft", SS_EmbedLeft },
   { "EmbedRight", SS_EmbedRight },
   { "EmbedNone", SS_EmbedNone },
+
+  { "Yudit", SS_Yudit_XPM },
   {  0, 0 }
 };
 
