@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -2461,6 +2458,7 @@ STextEdit::setDirection (SS_DR_Dir dir)
   case SS_DR_RO:
     if (current != SD_CD_RLO) needed = SD_CD_RLO;
     break;
+  default: break;
   }
   if (needed != 0)
   {
@@ -2524,26 +2522,27 @@ STextEdit::changeDirection (SS_DR_Dir dir)
   SS_DR_Dir cdir = caret.getDirection();
   switch (dir)
   {
-    case SS_DR_LE:
-      if (isEL&& !isOve) skip = true;
-      if (cdir==dir) skip = true;
-      if (cdir==SS_DR_RE) skip = true;
-      break;
-    case SS_DR_RE:
-      if (!isEL && !isOve) skip = true;
-      if (cdir==dir) skip = true;
-      if (cdir==SS_DR_LE) skip = true;
-      break;
-    case SS_DR_LO:
-      if (isEL && isOve) skip = true;
-      if (cdir==dir) skip = true;
-      if (cdir==SS_DR_RO) skip = true;
-      break;
-    case SS_DR_RO:
-      if (cdir==dir) skip = true;
-      if (!isEL && isOve) skip = true;
-      if (cdir==SS_DR_LO) skip = true;
-      break;
+  case SS_DR_LE:
+    if (isEL&& !isOve) skip = true;
+    if (cdir==dir) skip = true;
+    if (cdir==SS_DR_RE) skip = true;
+    break;
+  case SS_DR_RE:
+    if (!isEL && !isOve) skip = true;
+    if (cdir==dir) skip = true;
+    if (cdir==SS_DR_LE) skip = true;
+    break;
+  case SS_DR_LO:
+    if (isEL && isOve) skip = true;
+    if (cdir==dir) skip = true;
+    if (cdir==SS_DR_RO) skip = true;
+    break;
+  case SS_DR_RO:
+    if (cdir==dir) skip = true;
+    if (!isEL && isOve) skip = true;
+    if (cdir==SS_DR_LO) skip = true;
+    break;
+  default: break;   
   }
   if (skip && startSelection!=endSelection)
   {
@@ -2611,6 +2610,7 @@ STextEdit::changeDirection (SS_DR_Dir dir)
     case SS_DR_RE: em = SD_CD_RLE; break;
     case SS_DR_LO: em = SD_CD_LRO; break;
     case SS_DR_RO: em = SD_CD_RLO; break;
+    default: break;
     }
     for (unsigned int i=0; i<u4.size(); i++)
     {
