@@ -1,9 +1,6 @@
 /** *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -46,7 +43,7 @@
 typedef  SBinVector<unsigned short> SH_Vector;
 
 /**
- * @author: Gaspar Sinai <gsinai@yudit.org>
+ * @author: Gaspar Sinai <gaspar@yudit.org>
  * @version: 2000-04-23
  * This is the abstract widget toolkit font package
  */
@@ -124,7 +121,7 @@ protected:
     const SS_GlyphIndex* chars, unsigned int liglen, SS_GlyphIndex* out,
     unsigned int substtype = 4);
 
-  bool SFontTTF::hasOTFLigatures();
+  bool hasOTFLigatures();
 
   void getOTFMarkToBase (SS_GlyphIndex baseGlyph, 
        SS_GlyphIndex markGlyph, int* ix, int* iy);
