@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -35,7 +32,7 @@
 #endif
 
 /**
- * @author: Gaspar Sinai <gsinai@yudit.org>
+ * @author: Gaspar Sinai <gaspar@yudit.org>
  * @version: 2000-04-23
  * This is a postscript renderer for yudit.
  */
@@ -51,13 +48,89 @@ SPostscript::SPostscript (const SWriter& wr, SMedia m, SOrientation o)  : out (w
   unsigned int h;
   switch (m)
   {
+  case A3:
+    w = 842;
+    h = 1190;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
   case A4:
+    w = 595;
+    h = 842;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
+  case A5:
+    w = 420;
+    h = 595;
+    widthMargin = 45;
+    heightMargin = 34;
+    break;
+  case B4:
+    w = 792;
+    h = 1032;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
+  case B5:
+    w = 516;
+    h = 729;
+    widthMargin = 45;
+    heightMargin = 34;
+    break;
+  case Executive:
+    w = 540;
+    h = 720;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
+  case Folio:
+    w = 612;
+    h = 936;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
+  case Ledger:
+    w = 980;
+    h = 792;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
+  case Legal:
+    w = 612;
+    h = 1008;
+    widthMargin = 64;
+    heightMargin = 48;
+    break;
+  case Letter:
+    w = 612;
+    h = 792;
+    widthMargin = 24;
+    heightMargin = 34;
+    break;
+  case Quarto:
+    w = 610;
+    h = 780;
+    widthMargin = 24;
+    heightMargin = 48;
+    break;
+  case Statement:
+    w = 396;
+    h = 612;
+    widthMargin = 24;
+    heightMargin = 48;
+    break;
+  case Tabloid:
+    w = 792;
+    h = 1028;
+    widthMargin = 24;
+    heightMargin = 48;
+    break;
   default:
     w = 595;
     h = 842;
     widthMargin = 64;
     heightMargin = 48;
-    //heightMargin = 64;
   }
   if (o==PORTRAIT)
   {
@@ -137,10 +210,10 @@ SPostscript::open (bool background)
 
   bb.print (widthMargin); bb.append (" ");
   bb.print (heightMargin); bb.append (" ");
-  bb.print (width - 2 * widthMargin); bb.append (" ");
-  bb.print (height - 2 * heightMargin); bb.append (" ");
-  
-  head.append ("%%BoundingBox: 64 48 531 794");
+  bb.print (width - widthMargin); bb.append (" ");
+  bb.print (height - heightMargin); 
+  head.append (bb);
+
   head.append ("%%Title: Untitled");
   SString creator ("%%Creator: yudit "); creator.append (SD_YUDIT_VERSION);
   creator.append (" GNU (C) Gaspar Sinai");
@@ -168,7 +241,24 @@ SPostscript::open (bool background)
   SString m ("%%DocumentMedia: ");
   switch (media)
   {
+  case Legal:
+     m.append ("Legal "); break;
+  case Letter:
+     m.append ("Letter "); break;
+  case Tabloid:
+     m.append ("Tabloid "); break;
+  case Ledger:
+     m.append ("Ledger "); break;
+  case B4:
+     m.append ("B4 "); break;
+  case A3:
+     m.append ("A3 "); break;
   case A4:
+     m.append ("A4 "); break;
+  case A5:
+     m.append ("A5 "); break;
+  case B5:
+     m.append ("B5 "); break;
   default:
      m.append ("A4 ");
   }
