@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -444,14 +441,13 @@ fprintf (stderr, "\n");
  * Create two pixmaps, one for the image and one for the colored ones.
  * We use the same depth to avoid XCopyPlanes to gain speed
  * @param p is the image
- * @param m is the shape image. it contains 1's where ther is no image.
+ * @param m is the shape image. 
  */
 
 /* unsigned char in color is less that this -> transparent */
 
 void
-SX11Window::createColoredPixmap (const SImage& im, 
-     Pixmap* p, Pixmap* m)
+SX11Window::createColoredPixmap (const SImage& im, Pixmap* p, Pixmap* m)
 {
   int imageWidth = (int) im.getWidth();
   int imageHeight = (int) im.getHeight();
@@ -463,22 +459,21 @@ SX11Window::createColoredPixmap (const SImage& im,
      bits, (bits > 1? ZPixmap: XYBitmap), 0, (char*) image,
      imageWidth, imageHeight, 32, 0);
 
-  if (m != 0)
   /* First wipe out the shape */
+  if (m != 0)
   {
     for (int y=0; y<imageHeight; y++)
     {
       for (int x=0; x<imageWidth; x++)
       {
         SColor c (im.getShade (x, y));
-        SS_WORD32  rpvle = (c.alpha == 0) ? 0xffffff : 0;
+        SS_WORD32  rpvle = (c.alpha == 0) ? 0xffffff : 0x0;
         XPutPixel (ximage, x, y, rpvle); 
       }
     }
 
     Pixmap xshape = XCreatePixmap (impl->display, (Window) id, 
       im.getWidth(), im.getHeight(), bits);
-    //XSetClipMask (impl->display, gc_default, None);
     XPutImage (impl->display, xshape, gc_default, ximage, 0, 0, 0, 0, 
       im.getWidth(), im.getHeight());
     *m = xshape;
@@ -493,8 +488,6 @@ SX11Window::createColoredPixmap (const SImage& im,
       SColor bg (pen.getBackground());
       if (c.alpha != 0) bg.blend (c);
       SS_WORD32  rpvle = SX11Color(impl, bg).getPixelValue();
-//fprintf (stderr, "PIXEL=%lx=%lx ", (unsigned long) c.getValue(), rpvle);
-//fprintf (stderr, "PIXEL=%lx ", (unsigned long) rpvle);
       XPutPixel (ximage, x, y, rpvle); 
     }
   }
@@ -502,14 +495,13 @@ SX11Window::createColoredPixmap (const SImage& im,
   Pixmap xpixmap = XCreatePixmap (impl->display, (Window) id, 
      im.getWidth(), im.getHeight(), bits);
 
-
-  //XSetClipMask (impl->display, gc_default, None);
   XPutImage (impl->display, xpixmap, gc_default, ximage, 0, 0, 0, 0, 
      im.getWidth(), im.getHeight());
 
   XDestroyImage (ximage);
   *p = xpixmap;
 }
+
 /**
  * Create two pixmaps, one for the image and one for the shade.
  * We use the same depth to avoid XCopyPlanes to gain speed
@@ -517,8 +509,7 @@ SX11Window::createColoredPixmap (const SImage& im,
  * @param m is the shape image. it contains 1's where ther is no image.
  */
 void
-SX11Window::createShadedPixmap (const SImage& im, 
-     Pixmap* p, Pixmap* m)
+SX11Window::createShadedPixmap (const SImage& im, Pixmap* p, Pixmap* m)
 {
   int imageWidth = (int) im.getWidth();
   int imageHeight = (int) im.getHeight();
@@ -532,21 +523,18 @@ SX11Window::createShadedPixmap (const SImage& im,
 
   int i;
 
-  if (m != 0)
   /* First wipe out the shape */
+  if (m != 0)
   {
     for (int y=0; y<imageHeight; y++)
     {
       for (int x=0; x<imageWidth; x++)
       {
         SS_WORD32 sh = im.getShade (x, y);
-        SS_WORD32  rpvle = (sh==0) ? 0xffffff : 0;
+        SS_WORD32  rpvle = (sh==0) ? 0xffffff : 0x0;
         XPutPixel (ximage, x, y, rpvle); 
       }
     }
-
-//fprintf (stderr,"Created image shade %u %u\n", im.getWidth(), im.getHeight());
-//XSetClipMask (impl->display, gc_default, None);
     Pixmap xshape = XCreatePixmap (impl->display, (Window) id, 
       im.getWidth(), im.getHeight(), bits);
 
@@ -589,8 +577,6 @@ SX11Window::createShadedPixmap (const SImage& im,
   Pixmap xpixmap = XCreatePixmap (impl->display, (Window) id, 
      im.getWidth(), im.getHeight(), bits);
 
-//fprintf (stderr, "Created image %u %u\n", im.getWidth(), im.getHeight());
-//XSetClipMask (impl->display, gc_default, None);
   XPutImage (impl->display, xpixmap, gc_default, ximage, 0, 0, 0, 0, 
      im.getWidth(), im.getHeight());
 
@@ -604,6 +590,76 @@ SX11Window::createShadedPixmap (const SImage& im,
   *p = xpixmap;
 }
 
+/**
+ * @param im is the image
+ * @param p where the image will be put.
+ * @param m is the shape bitmap. 
+ */
+void
+SX11Window::createMaskedPixmap (const SImage& im, Pixmap* p, Pixmap* m)
+{
+  int imageWidth = (int) im.getWidth();
+  int imageHeight = (int) im.getHeight();
+
+  /* First wipe out the shape */
+  if (m != 0)
+  {
+    Pixmap xshape = XCreatePixmap (impl->display, (Window) id, 
+       im.getWidth(), im.getHeight(), 1);
+    XGCValues   gcv;
+    gcv.background = 0x0;
+    gcv.foreground = 0x0;
+    GC sgc = XCreateGC (impl->display, xshape, GCForeground
+       | GCBackground, &gcv); 
+    XFillRectangle (impl->display, xshape, sgc, 0, 0, imageWidth, imageHeight);
+    XSetForeground (impl->display, sgc, 0x1);
+
+    for (int y=0; y<imageHeight; y++)
+    {
+      for (int x=0; x<imageWidth; x++)
+      {
+        SColor c (im.getShade (x, y));
+        if (c.alpha != 0)
+        {
+          XDrawPoint (impl->display, xshape, sgc, x, y);
+        }
+      }
+    }
+    *m = xshape;
+    XFreeGC (impl->display, sgc);
+  }
+
+  int bits = DefaultDepth (impl->display, impl->screen);
+
+  SS_WORD32* image = new SS_WORD32[imageWidth*imageHeight];
+
+  XImage* ximage = XCreateImage (impl->display, impl->visual,
+     bits, (bits > 1? ZPixmap: XYBitmap), 0, (char*) image,
+     imageWidth, imageHeight, 32, 0);
+
+  /* Then blot the image */
+  for (int y=0; y<imageHeight; y++)
+  {
+    for (int x=0; x<imageWidth; x++)
+    {
+      SColor c (im.getShade (x, y));
+      SColor bg (pen.getBackground());
+      if (c.alpha != 0) bg.blend (c);
+      SS_WORD32  rpvle = SX11Color(impl, bg).getPixelValue();
+      XPutPixel (ximage, x, y, rpvle); 
+    }
+  }
+
+  Pixmap xpixmap = XCreatePixmap (impl->display, (Window) id, 
+     im.getWidth(), im.getHeight(), bits);
+
+  XPutImage (impl->display, xpixmap, gc_default, ximage, 0, 0, 0, 0, 
+     im.getWidth(), im.getHeight());
+
+  XDestroyImage (ximage);
+  *p = xpixmap;
+}
+
 void
 SX11Window::setBackground(const SColor &color)
 {
@@ -707,7 +763,7 @@ SX11Window::setParent (SWindow* w, int x, int y)
 }
 
 /**
- * Clear a reagion (set it to the background)
+ * Clear a region (set it to the background)
  * @param x is the upper left corner
  * @param y is the upper top corner
  * @param width is the width of the region to clear
@@ -803,6 +859,9 @@ SX11Window::bitpoints (const SColor& fg, const int* _x, const int* _y,
   {
     XSetForeground (impl->display, gc, SX11Color(impl, fg).getPixelValue());
     gcFG = (unsigned long)  fg.getValue();
+    // If I don't do XSync there is a point drawing error of 
+    // highlighted text on Matrox Video card with X64
+    // XSync (impl->display, False);
   }
   XPoint* p = new XPoint[_size];
   CHECK_NEW (p);
@@ -875,6 +934,27 @@ SX11Window::getCurrentMatrix() const
   return SS_Matrix2D();
 }
 
+// TODO: implement this.
+void 
+SX11Window::setApplicationImage (const SImage& im)
+{
+  Pixmap pixmap = 0;
+  Pixmap mask = 0;
+  createMaskedPixmap (im, &pixmap, &mask); 
+  //XWMHints *hints = XGetWMHints(impl->display, (Window) id);
+  XWMHints *hints = XAllocWMHints();
+  if (!pixmap ||!mask || !hints)
+  {
+    return;
+  }
+  hints->flags |= IconPixmapHint;
+  hints->icon_pixmap = pixmap;
+  hints->flags |= IconMaskHint;
+  hints->icon_mask = mask;
+  XSetWMHints(impl->display, (Window) id, hints); 
+  XFree (hints);
+}
+
 /**
  * This reqests a redraw, efficiently after all events got processed.
  * This is called by the client and not by SX11Impl.
