@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -34,7 +31,7 @@
 #include "stoolkit/SVector.h"
 
 /**
- * @author: Gaspar Sinai <gsinai@yudit.org>
+ * @author: Gaspar Sinai <gaspar@yudit.org>
  * @version: 2000-04-23
  * This is the abstract widget toolkit
  */
@@ -50,6 +47,7 @@ public:
   virtual bool cacheOn (bool on=true);
 
   virtual SS_Matrix2D  getCurrentMatrix() const;
+
   virtual void setMinimumSize (unsigned int width, unsigned int height);
 
   /* Low level routines */
@@ -60,6 +58,8 @@ public:
   virtual void show ();
   virtual void hide ();
 
+  virtual void setApplicationImage (const SImage& im);
+
   /*---------------- from canvas --------------*/
   virtual bool newpath (double x, double y, const SString& id);
   virtual void fill (const SPen& pen);
@@ -138,8 +138,10 @@ public:
 
 private:
   SBinHashtable <SAcceleratorListener*> accelerators;
-  void SX11Window::createShadedPixmap (const SImage& im, Pixmap* p, Pixmap* m);
-  void SX11Window::createColoredPixmap (const SImage& im, Pixmap* p, Pixmap* m);
+  void createShadedPixmap (const SImage& im, Pixmap* p, Pixmap* m);
+  void createColoredPixmap (const SImage& im, Pixmap* p, Pixmap* m);
+  void createMaskedPixmap (const SImage& im, Pixmap* p, Pixmap* m);
+
   SString         name;
   SXInputMethod inputMethod;
   SPen		pen;
