@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -284,11 +281,11 @@ SXInputMethod::setProperties (const SProperties& props)
         XPoint spot; spot.x = x; spot.y = y;
 
         XVaNestedList attributes = XVaCreateNestedList (0, 
-          XNSpotLocation, &spot, 0);
+          XNSpotLocation, &spot, (char *) 0x0);
 
         if (attributes) 
         {
-          XSetICValues(xic, XNPreeditAttributes, attributes, 0);
+          XSetICValues(xic, XNPreeditAttributes, attributes, (char *) 0x0);
           XFree (attributes);
         }
       }
@@ -316,16 +313,16 @@ SXInputMethod::setProperties (const SProperties& props)
         statusArea.y = statusY;
 
         XVaNestedList ca = XVaCreateNestedList (0, 
-          XNSpotLocation, &spot, 0);
+          XNSpotLocation, &spot, (char *) 0x0);
 
         XVaNestedList sa = XVaCreateNestedList (0, 
-          XNArea, &statusArea, 0);
+          XNArea, &statusArea, (char *) 0x0);
 
         if (ca && sa) 
         {
           XSetICValues(xic, 
               XNPreeditAttributes, ca, 
-              XNStatusAttributes, sa, 0);
+              XNStatusAttributes, sa, (char *) 0x0);
           XFree (ca);
           XFree (sa);
         }
@@ -952,7 +949,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
   XIMCallback  imCallback;
   imCallback.client_data = (char*)&xim;
   imCallback.callback = (XIMProc) destroyIMCB;
-  XSetIMValues (xim, XNDestroyCallback , &imCallback , 0);
+  XSetIMValues (xim, XNDestroyCallback , &imCallback , (char *) 0x0);
 #endif
   if (ps.get ("InputStyle") == 0) ps.put ("InputStyle", "none");
   SString s = ps["InputStyle"];
@@ -990,7 +987,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
   inputStyle = s;
 
   XIMStyles* xim_styles;
-  if (XGetIMValues(xim, XNQueryInputStyle, &xim_styles, 0)
+  if (XGetIMValues(xim, XNQueryInputStyle, &xim_styles, (char *) 0x0)
       || xim_styles==0 || xim_styles->count_styles==0)
   {
       fprintf (stderr, "input method doesn't support any style\n");
@@ -1080,7 +1077,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
       XNBackground , WhitePixel (impl->display, screen),
       XNSpotLocation, &spot,
       XNFontSet, fontSet,
-      0);
+      (char *) 0x0);
     if (attributes==0)
     {
       XCloseIM(xim);
@@ -1092,10 +1089,10 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
        XNInputStyle, code,
        XNClientWindow, (Window) id,
        XNPreeditAttributes, attributes,
-       0);
+       (char *) 0x0);
     XFree (attributes);
     //Bool preedit_state = 1;
-    //if (xic) XSetICValues (xic, XNPreeditState, preedit_state, 0);
+    //if (xic) XSetICValues (xic, XNPreeditState, preedit_state, (char *) 0x0);
     if (props.get ("InputClientColor"))
     {
       SString col = props["InputClientColor"];
@@ -1107,10 +1104,10 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
       XVaNestedList atts = XVaCreateNestedList (0, 
        XNForeground, xfg.getPixelValue(),
        XNBackground, xbg.getPixelValue(),
-       0);
+       (char *) 0x0);
       if (atts) 
       {
-        XSetICValues(xic, XNPreeditAttributes, atts, 0);
+        XSetICValues(xic, XNPreeditAttributes, atts, (char *) 0x0);
         XFree (atts);
       }
     }
@@ -1167,14 +1164,14 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
       XNBackground , sxbg.getPixelValue(),
       XNFontSet, fontSet,
       XNArea, &statusArea,
-      0);
+      (char *) 0x0);
 
     XVaNestedList ca = XVaCreateNestedList (0, 
       XNForeground , cxfg.getPixelValue(),
       XNBackground , cxbg.getPixelValue(),
       XNFontSet, fontSet,
       XNArea, &clientArea,
-      0);
+      (char *) 0x0);
 
     if (sa==0 || ca==0)
     {
@@ -1192,7 +1189,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
        XNFocusWindow, (Window) id,
        XNPreeditAttributes, ca,
        XNStatusAttributes, sa,
-       0);
+       (char *) 0x0);
     XFree (ca);
     XFree (sa);
   }
@@ -1231,7 +1228,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
       XNBackground , sxbg.getPixelValue(),
       XNFontSet, fontSet,
       XNArea, &statusArea,
-      0);
+      (char *) 0x0);
 
     XPoint spot = {1, 1};
     XVaNestedList ca = XVaCreateNestedList (0, 
@@ -1239,7 +1236,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
       XNBackground , cxbg.getPixelValue(),
       XNSpotLocation, &spot,
       XNFontSet, fontSet,
-      0);
+      (char *) 0x0);
 
     if (sa==0 || ca==0)
     {
@@ -1254,7 +1251,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
        XNFocusWindow, (Window) id,
        XNPreeditAttributes, ca,
        XNStatusAttributes, sa,
-       0);
+       (char *) 0x0);
     XFree (ca);
     XFree (sa);
   }
@@ -1263,7 +1260,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
     xic = XCreateIC(xim, XNInputStyle, code,
        XNClientWindow, (Window) id,
        XNFocusWindow, (Window) id,
-       0);
+       (char *) 0x0);
   }
   if (xic==0) 
   {
@@ -1279,7 +1276,7 @@ SXInputMethod::createIC (const SString& str, const SProperties& props)
   xim_ev_mask |= KeyPressMask|KeyReleaseMask;
   XSetICValues (xic , XNFilterEvents , &xim_ev_mask , NULL);
 
-  //XSetICValues(xic, XNResetState, XIMPreserveState, (char *) 0);
+  //XSetICValues(xic, XNResetState, XIMPreserveState, (char *) 0x0);
   eventMask |= xim_ev_mask;
 
   XSelectInput (impl->display, (Window) id, eventMask);
