@@ -1,10 +1,7 @@
 /** 
  *  Yudit Unicode Editor Source File
  *
- *  GNU Copyright (C) 2003  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2002  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2001  Gaspar Sinai <gsinai@yudit.org>  
- *  GNU Copyright (C) 2000  Gaspar Sinai <gsinai@yudit.org>  
+ *  GNU Copyright (C) 1997-2006  Gaspar Sinai <gaspar@yudit.org>  
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -44,7 +41,7 @@ static void usage ();
 #define SS_MAC 2
 /**
  * This is a stoolkit encoder/decoder
- * @author: Gaspar Sinai <gsinai@yudit.org>
+ * @author: Gaspar Sinai <gaspar@yudit.org>
  * @version: 2000-04-23
  * This library is not multi-threaded. Therefor we need event handlers.
  */
@@ -254,14 +251,14 @@ usage ()
   SString supExt = extEnc.join(", ");
 
 
-  fprintf (stderr, version, SD_YUDIT_VERSION);
-  fprintf (stderr,   "USAGE: uniconv [-out file] [-in file] [-decode name] [-encode name] [-fromdos] [-todos] [-frommac] [-tomac] \n\n");
-  fprintf (stderr, "Currently known built-in encodings:   \n");
-  fprintf (stderr, "%*.*s\n\n", SSARGS(supStr));
-  fprintf (stderr, "Currently known external encodings:   \n");
-  fprintf (stderr, "%*.*s\n\n", SSARGS(supExt));
-  fprintf (stderr, "datapath settings:\n %*.*s.\n\n", SSARGS(pathStr));
-  fprintf (stderr, "example: /uniconv -decode Hungarian -encode iso-8859-2\n");
-  fprintf (stderr, "example: Sinai Ga'spa'r <eof>\n");
+  fprintf (stdout, version, SD_YUDIT_VERSION);
+  fprintf (stdout,   "USAGE: uniconv [-out file] [-in file] [-decode name] [-encode name] [-fromdos] [-todos] [-frommac] [-tomac] \n\n");
+  fprintf (stdout, "Currently known built-in encodings:   \n");
+  fprintf (stdout, "%*.*s\n\n", SSARGS(supStr));
+  fprintf (stdout, "Currently known external encodings:   \n");
+  fprintf (stdout, "%*.*s\n\n", SSARGS(supExt));
+  fprintf (stdout, "datapath settings:\n %*.*s.\n\n", SSARGS(pathStr));
+  fprintf (stdout, "example: /uniconv -decode Hungarian -encode iso-8859-2\n");
+  fprintf (stdout, "example: Sinai Ga'spa'r <eof>\n");
 }
 
